@@ -597,9 +597,11 @@ eog_collection_view_create_ui (EogCollectionView *view)
 	priv = view->priv;
 
 	/* Set up the UI from an XML file. */
-        bonobo_ui_util_set_ui (priv->uic, DATADIR,
-			       "eog-collection-view-ui.xml", "EogCollectionView", NULL);
+	bonobo_ui_util_set_ui (priv->uic, DATADIR,
+						   "eog-collection-view-ui.xml", "EogCollectionView", NULL);
 
+	bonobo_ui_component_set_prop (priv->uic, "/menu/Edit/Eog EditPreferences Separator",
+								  "hidden", "0", NULL);
 	bonobo_ui_component_add_verb_list_with_data (priv->uic,
 						     collection_verbs,
 						     view);
@@ -1110,8 +1112,6 @@ load_uri_cb (BonoboPersistFile *pf, const CORBA_char *text_uri,
 
 	}
 
-	g_print ("load_uri_cb: %s\n", (char*) text_uri);
-
 	eog_collection_model_add_uri (priv->model, (gchar*)text_uri); 
 
 	return 0;
@@ -1282,8 +1282,6 @@ eog_collection_view_construct (EogCollectionView *list_view)
 	/* UI Component */
 	priv->uic = bonobo_ui_component_new ("EogCollectionView");
 
-	bonobo_object_dump_interfaces (BONOBO_OBJECT (list_view));
-
 	return list_view;
 }
 
